@@ -12,10 +12,12 @@ from distutils.errors import (DistutilsOptionError, DistutilsPlatformError,
     DistutilsSetupError)
 from distutils.util import rfc822_escape
 
-import six
-from six.moves import map
-import packaging.specifiers
-import packaging.version
+from setuptools.extern import six
+from setuptools.extern.six.moves import map
+from pkg_resources.extern import packaging
+
+__import__('pkg_resources.extern.packaging.specifiers')
+__import__('pkg_resources.extern.packaging.version')
 
 from setuptools.depends import Require
 from setuptools import windows_support
